@@ -72,3 +72,13 @@ def s3_server():
     process = start_service('s3', host, port)
     yield url
     stop_process(process)
+
+
+@pytest.yield_fixture(scope="session")
+def kms_server():
+    host = "localhost"
+    port = 5003
+    url = "http://{host}:{port}".format(host=host, port=port)
+    process = start_service('kms', host, port)
+    yield url
+    stop_process(process)
