@@ -82,6 +82,27 @@ async def test_s3_upload_fileobj(event_loop, s3_client, bucket_name):
     assert (await resp['Body'].read()) == data
 
 
+@pytest.mark.asyncio
+async def test_s3_upload_broken_fileobj(event_loop, s3_client, bucket_name):
+    class BrokenFile(object):
+        def __init__(self, data: bytes):
+            self._data = data
+
+        def read(self, count):
+            raise IOError("some bad file")
+
+    await s3_client.create_bucket(Bucket=bucket_name)
+
+    fh = BrokenFile(b'Hello World\n')
+    try:
+        await s3_client.upload_fileobj(fh, bucket_name, 'test_file')
+    except Exception as err:
+        print()
+
+    uploads_resps = await s3_client.list_multipart_uploads(Bucket=bucket_name)
+    assert len(uploads_resps.get('Uploads', [])) == 0
+
+
 @pytest.mark.asyncio
 async def test_s3_upload_fileobj_with_transform(event_loop, s3_client, bucket_name):
     data = b'Hello World\n'
@@ -200,3 +221,14 @@ async def test_s3_resource_objects_delete_filter(event_loop, s3_client, s3_resou
 
     assert len(files) == 1
     assert files[0] == 'test/file1'
+
+
+@pytest.mark.asyncio
+async def test_s3_object_summary_load(event_loop, s3_client, s3_resource, bucket_name):
+    data = b'Hello World\n'
+    await s3_client.create_bucket(Bucket=bucket_name)
+    await s3_client.put_object(Bucket=bucket_name, Key='test_file', Body=data)
+
+    obj = await s3_resource.ObjectSummary(bucket_name, 'test_file')
+    obj_size = await obj.size
+    assert obj_size == len(data)
